"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gensequence_1 = require("gensequence");
const iterableToStream_1 = require("hunspell-reader/dist/iterableToStream");
const util_1 = require("hunspell-reader/dist/util");
const cspell_lib_1 = require("cspell-lib");
var cspell_lib_2 = require("cspell-lib");
exports.writeToFile = cspell_lib_2.writeToFile;
exports.writeToFileIterableP = cspell_lib_2.writeToFileIterableP;
exports.writeToFileIterable = cspell_lib_2.writeToFileIterable;
function writeSeqToFile(seq, outFile) {
    if (outFile) {
        return cspell_lib_1.writeToFileIterableP(outFile, seq);
    }
    return new Promise((resolve, reject) => {
        let resolved = false;
        const out = process.stdout;
        const bufferedSeq = gensequence_1.genSequence(util_1.batch(seq, 500)).map(batch => batch.join(''));
        const dataStream = iterableToStream_1.iterableToStream(bufferedSeq);
        const fileStream = dataStream.pipe(out);
        const endEvents = ['finish', 'close', 'end'];
        function resolvePromise() {
            if (!resolved) {
                resolved = true;
                resolve();
            }
        }
        const endHandler = () => {
            cleanupStreams();
            setTimeout(resolvePromise, 10);
        };
        const errorHandler = (e) => {
            cleanupStreams();
            reject(e);
        };
        listenToStreams();
        function listenToStreams() {
            endEvents.forEach(event => fileStream.addListener(event, endHandler));
            fileStream.addListener('error', errorHandler);
            dataStream.addListener('end', endHandler);
        }
        function cleanupStreams() {
            endEvents.forEach(event => fileStream.removeListener(event, endHandler));
            fileStream.removeListener('error', errorHandler);
            dataStream.removeListener('end', endHandler);
        }
    });
}
exports.writeSeqToFile = writeSeqToFile;
//# sourceMappingURL=fileWriter.js.map